"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable no-console */

const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);

// Default empty arrays as stable references
const DEFAULT_LANGUAGES = [];
const DEFAULT_THEMES = [];
const DEBUG = true;
function log(...args) {
  if (DEBUG) {
    console.log('[ShikiProvider]', ...args);
  }
}
function ShikiProvider({
  children,
  initialLanguages = DEFAULT_LANGUAGES,
  initialThemes = DEFAULT_THEMES
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const initializeHighlighter = async () => {
      try {
        log('Initializing highlighter...');
        const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
          forgiving: true,
          cache: new Map()
        });

        // Create the highlighter with explicit options
        const instance = await (0, _core.createHighlighterCore)({
          engine,
          langs: initialLanguages,
          themes: initialThemes
        });

        // Test tokenization
        const {
          tokens: testTokens
        } = instance.codeToTokens('function test() { return true; }', {
          lang: 'typescript',
          theme: 'github-dark',
          includeExplanation: true
        });
        log('Test tokenization:', {
          tokens: testTokens[0]?.map(t => ({
            content: t.content,
            color: t.color,
            scopes: t.explanation?.[0]?.scopes
          }))
        });
        setHighlighter(instance);
        setIsReady(true);
      } catch (err) {
        console.error('Full error:', err);
        setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
      }
    };
    initializeHighlighter();
  }, [initialLanguages, initialThemes]);
  const registerLanguage = (0, _react.useCallback)(async lang => {
    if (!highlighter) {
      log('Cannot register language, highlighter not ready:', lang.name);
      return;
    }
    try {
      log('Registering language:', lang.name);
      await highlighter.loadLanguage(lang);
      log('Language registered:', lang.name);
    } catch (err) {
      log('Error registering language:', lang.name, err);
    }
  }, [highlighter]);
  const registerTheme = (0, _react.useCallback)(async theme => {
    if (!highlighter) {
      log('Cannot register theme, highlighter not ready:', typeof theme === 'string' ? theme : theme.name);
      return;
    }
    try {
      log('Registering theme:', typeof theme === 'string' ? theme : theme.name);
      await highlighter.loadTheme(theme);
      log('Theme registered:', typeof theme === 'string' ? theme : theme.name);
    } catch (err) {
      log('Error registering theme:', typeof theme === 'string' ? theme : theme.name, err);
    }
  }, [highlighter]);
  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error,
    registerLanguage,
    registerTheme,
    getLoadedLanguages: () => {
      const langs = highlighter?.getLoadedLanguages() || [];
      log('Getting loaded languages:', langs);
      return langs;
    },
    getLoadedThemes: () => {
      const themes = highlighter?.getLoadedThemes() || [];
      log('Getting loaded themes:', themes);
      return themes;
    }
  }), [highlighter, isReady, error, registerLanguage, registerTheme]);
  (0, _react.useEffect)(() => {
    log('ShikiProvider mounted');
    return () => log('ShikiProvider unmounted');
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}

// Add logging to hook usage
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    log('useShiki called outside of provider!');
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map