"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _style = require("../utils/style");
var _SyntaxContext = require("./SyntaxContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable no-console */

const DEBUG = true;
function log(...args) {
  if (DEBUG) {
    console.log('[SyntaxHighlighter]', ...args);
  }
}
const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  content: {
    padding: 10
  },
  line: {
    flexDirection: 'row'
  },
  lineContent: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  lineNumber: {
    width: 40,
    paddingRight: 8,
    opacity: 0.5
  },
  lineNumberText: {
    textAlign: 'right'
  },
  error: {
    color: '#ff6b6b'
  },
  bold: {
    fontWeight: 'bold'
  },
  italic: {
    fontStyle: 'italic'
  },
  underline: {
    textDecorationLine: 'underline'
  }
});
const SyntaxHighlighter = exports.SyntaxHighlighter = /*#__PURE__*/(0, _react.memo)(({
  code,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle,
  showLineNumbers = false,
  renderLineNumber,
  loadingComponent,
  errorComponent
}) => {
  const {
    highlighter,
    isReady
  } = (0, _SyntaxContext.useShiki)();
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [loading, setLoading] = (0, _react.useState)(true);
  const [error, setError] = (0, _react.useState)(null);

  // Only get root styles from theme
  const stylesheet = _react.default.useMemo(() => {
    const styles = (0, _style.getStylesFromShikiTheme)(theme);
    log('Generated stylesheet from theme:', {
      themeName: typeof theme === 'string' ? theme : theme.name,
      rootStyle: styles.root
    });
    return styles;
  }, [theme]);
  const highlight = (0, _react.useCallback)(async () => {
    if (!highlighter || !isReady) return;
    try {
      setLoading(true);
      setError(null);

      // Get theme name safely
      const themeName = typeof theme === 'string' ? theme : theme.name || 'default';

      // Convert language to string if it's a LanguageRegistration
      const langName = typeof language === 'string' ? language : language.name;

      // Ensure theme is loaded
      if (!highlighter.getLoadedThemes().includes(themeName)) {
        // Cast theme to ThemeRegistrationAny when loading
        await highlighter.loadTheme(typeof theme === 'string' ? {
          name: theme
        } : theme);
      }

      // Use codeToTokens with proper typing
      const result = highlighter.codeToTokens(code, {
        lang: langName,
        theme: themeName,
        includeExplanation: true
      });
      log('Tokenization result:', {
        lines: result.tokens.length,
        firstLineTokens: result.tokens[0]?.length,
        firstLineDetails: result.tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          fontStyle: t.fontStyle,
          scopes: t.explanation?.[0]?.scopes
        }))
      });
      setTokens(result.tokens);
    } catch (err) {
      console.error('Full highlighting error:', err);
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    } finally {
      setLoading(false);
    }
  }, [code, language, theme, highlighter, isReady]);
  (0, _react.useEffect)(() => {
    highlight();
  }, [highlight]);
  const renderToken = (0, _react.useCallback)((token, lineIndex, tokenIndex) => {
    // Get the token's color and font style from Shiki
    const tokenStyle = {
      color: token.color,
      // Use the color directly from Shiki
      fontSize,
      ...(token.fontStyle && token.fontStyle & 1 && {
        fontStyle: 'italic'
      }),
      ...(token.fontStyle && token.fontStyle & 2 && {
        fontWeight: 'bold'
      }),
      ...(token.fontStyle && token.fontStyle & 4 && {
        textDecorationLine: 'underline'
      })
    };
    if (DEBUG && lineIndex === 0 && tokenIndex === 0) {
      log('Rendering token:', {
        content: token.content,
        color: token.color,
        fontStyle: token.fontStyle,
        computedStyle: tokenStyle
      });
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: [tokenStyle, textStyle],
      selectable: false,
      children: token.content
    }, `${lineIndex}-${tokenIndex}`);
  }, [fontSize, textStyle]);
  const renderLine = (0, _react.useCallback)((lineTokens, lineIndex) => {
    if (DEBUG && lineIndex === 0) {
      log('Rendering first line:', {
        tokenCount: lineTokens.length,
        tokens: lineTokens.map(t => ({
          content: t.content,
          color: t.color
        }))
      });
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: styles.line,
      children: [showLineNumbers && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.lineNumber,
        children: renderLineNumber ? renderLineNumber(lineIndex + 1) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: styles.lineNumberText,
          children: (lineIndex + 1).toString().padStart(3, ' ')
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.lineContent,
        children: lineTokens.map((token, tokenIndex) => renderToken(token, lineIndex, tokenIndex))
      })]
    }, lineIndex);
  }, [renderToken, showLineNumbers, renderLineNumber]);
  (0, _react.useEffect)(() => {
    log('Component mounted with props:', {
      language,
      theme: typeof theme === 'string' ? theme : theme.name,
      isReady,
      hasHighlighter: !!highlighter
    });
    return () => log('Component unmounted');
  }, [language, theme, isReady, highlighter]);
  if (loading) {
    return loadingComponent || /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [styles.container, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return errorComponent?.(error) || /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [styles.container, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: styles.error,
        children: ["Error:", error]
      })
    });
  }
  const combinedStyle = [styles.container, stylesheet.root, scrollViewProps?.style];
  log('Rendering with styles:', {
    containerStyle: combinedStyle,
    tokenCount: tokens.reduce((acc, line) => acc + line.length, 0)
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    style: combinedStyle,
    contentContainerStyle: [styles.content, containerStyle],
    horizontal: true,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map